api.reputation.v1.test_helpers.source package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.test_helpers.source package

## Submodules

## api.reputation.v1.test_helpers.source.add_new_source module

`api.reputation.v1.test_helpers.source.add_new_source.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 403

`api.reputation.v1.test_helpers.source.add_new_source.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 404

`api.reputation.v1.test_helpers.source.add_new_source.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 200

`api.reputation.v1.test_helpers.source.add_new_source.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 401

## api.reputation.v1.test_helpers.source.delete_source module

`api.reputation.v1.test_helpers.source.delete_source.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.source.delete_source.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.source.delete_source.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.source.delete_source.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.source.find_sources module

`api.reputation.v1.test_helpers.source.find_sources.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/search, respond with HTTP 403

`api.reputation.v1.test_helpers.source.find_sources.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/search, respond with HTTP 404

`api.reputation.v1.test_helpers.source.find_sources.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/search, respond with HTTP 200

`api.reputation.v1.test_helpers.source.find_sources.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/search, respond with HTTP 401

## api.reputation.v1.test_helpers.source.get_source_by_alias module

`api.reputation.v1.test_helpers.source.get_source_by_alias.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.source.get_source_by_alias.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.source.get_source_by_alias.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.source.get_source_by_alias.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.source.get_source_by_id module

`api.reputation.v1.test_helpers.source.get_source_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.source.get_source_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.source.get_source_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.source.get_source_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.source.list_sources module

`api.reputation.v1.test_helpers.source.list_sources.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 403

`api.reputation.v1.test_helpers.source.list_sources.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 404

`api.reputation.v1.test_helpers.source.list_sources.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 200

`api.reputation.v1.test_helpers.source.list_sources.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source, respond with HTTP 401

## api.reputation.v1.test_helpers.source.update_source module

`api.reputation.v1.test_helpers.source.update_source.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.source.update_source.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.source.update_source.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.source.update_source.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/source/w+, respond with HTTP 401

## Module contents